import ee
from ee_plugin import Map

Map.setCenter(lon = 17.7, lat = 46.9, zoom = 12) # Balaton
# legyen WGS-84-ben (EPSG: 4326) a projekt!
teglalap = Map.getBounds(asGeoJSON = True) # az ábrázolt téglalap alakú kivágat poligonként
tiszta_kepek = (ee.ImageCollection("LANDSAT/LC09/C02/T1_L2")
	.filterBounds(teglalap)
	.filter(ee.Filter.lte("CLOUD_COVER", 20)))
megjelenites = {"bands": ["SR_B4", "SR_B3", "SR_B2"],
	"min": 7000,
	"max": 20000}
Map.setZoom(8)

nyari_2022_1 = tiszta_kepek.filterDate("2022-06-01", "2022-08-31")
Map.addLayer(eeObject = nyari_2022_1.median(), visParams = megjelenites, name = "2022. nyári képek mediánja - 1. verzió")

nyari_2022_2 = tiszta_kepek.filter(ee.Filter.date("2022-06-01", "2022-08-31"))
Map.addLayer(eeObject = nyari_2022_2.median(), visParams = megjelenites, name = "2022. nyári képek mediánja - 2. verzió")

nyari_2022_3 = (tiszta_kepek
	.filter(ee.Filter.calendarRange(2022, 2022, "year"))
	.filter(ee.Filter.calendarRange(6, 8, "month")))
Map.addLayer(eeObject = nyari_2022_3.median(), visParams = megjelenites, name = "2022. nyári képek mediánja - 3. verzió")

nyari_2022_4 = (tiszta_kepek
	.filter(ee.Filter.And(
		ee.Filter.calendarRange(start = 2022, field = "year"),
		ee.Filter.dayOfYear(start = 152, end = 243))))
Map.addLayer(eeObject = nyari_2022_4.median(), visParams = megjelenites, name = "2022. nyári képek mediánja - 4. verzió")

tavaszi_vagy_tavalyi_hetvegi = (tiszta_kepek
	.filter(ee.Filter.calendarRange(start = 6, end = 7, field = "day_of_week"))
	.filter(ee.Filter.Or(
		ee.Filter.calendarRange(start = 2022, field = "year"),
		ee.Filter.calendarRange(start = 3, end = 5, field = "month"))))
Map.addLayer(eeObject = tavaszi_vagy_tavalyi_hetvegi.max(), visParams = megjelenites, name = "tavasszal vagy tavaly készült hétvégi képek maximuma")


