import ee
from ee_plugin import Map

Map.setCenter(lon = 17.7, lat = 46.9, zoom = 12) # Balaton
# legyen WGS-84-ben (EPSG: 4326) a projekt!
teglalap = Map.getBounds(asGeoJSON = True) # az ábrázolt téglalap alakú kivágat poligonként
levalogatott = (ee.ImageCollection("LANDSAT/LC09/C02/T1_L2")
	.filterBounds(teglalap)
	.filterDate("2022-03-01", "2023-10-31"))
megjelenites = {"bands": ["SR_B4", "SR_B3", "SR_B2"],
	"min": 7000,
	"max": 20000}

nagyon_felhosek = levalogatott.filter(ee.Filter.gte("CLOUD_COVER", 80))
Map.addLayer(eeObject = nagyon_felhosek.first(), visParams = megjelenites, name = "nagyon felhős képek egyike")

deli_felhotlen = (levalogatott
	.filter(ee.Filter.gt("SUN_ELEVATION", 40))
	.filter(ee.Filter.lte("CLOUD_COVER", 20)))
Map.addLayer(eeObject = deli_felhotlen.mean(), visParams = megjelenites, name = "déli felhőtlen képek átlaga")

kozepesen_felhos_reggeli = (levalogatott
	.filter(ee.Filter.gte("SUN_AZIMUTH", 45))
	.filter(ee.Filter.rangeContains("CLOUD_COVER", 30, 70)))
Map.addLayer(eeObject = kozepesen_felhos_reggeli.median(), visParams = megjelenites, name = "közepesen felhős reggeli képek mediánja")

Map.setZoom(5) # kizoomolunk
orszagok = ee.FeatureCollection("USDOS/LSIB/2017")
nehany_orszag = (orszagok.filter(ee.Filter.Or(
	ee.Filter.inList("COUNTRY_NA", ["Belgium", "Austria", "Slovakia", "Slovenia"]),
	ee.Filter.gt("Shape_Area", 1000))))
Map.addLayer(eeObject = nehany_orszag, visParams = {}, name = "néhány ország")

Map.setCenter(lon = 17, lat = 46, zoom = 8)
nagyobb_teglalap = Map.getBounds(asGeoJSON = True)
osszemetszodo_kicsi = (orszagok.filter(ee.Filter.And(
	ee.Filter.intersects(".geo", nagyobb_teglalap),
	ee.Filter.lt("Shape_Area", 10))))
Map.addLayer(eeObject = osszemetszodo_kicsi, visParams = {}, name = "összemetsződő kis országok")
Map.setZoom(7)

tartalmazo_vagy_tartalmazott = (orszagok.filter(ee.Filter.Or(
	ee.Filter.contains(".geo", teglalap),
	ee.Filter.isContained(".geo", nagyobb_teglalap))))
Map.addLayer(eeObject = tartalmazo_vagy_tartalmazott, visParams = {"color": "red"}, name = "összemetsződő kis országok")
