import ee
from ee_plugin import Map

# Előző feladatból:
orszagok = ee.FeatureCollection("USDOS/LSIB/2017")
brit_szigetek_2 = orszagok.filter(ee.Filter.inList("COUNTRY_NA", ["Ireland", "United Kingdom"]))
Map.centerObject(brit_szigetek_2, 8)
teglalap = Map.getBounds(asGeoJSON = True)
Map.setZoom(7)
megjelenites = {"bands": ["SR_B4", "SR_B3", "SR_B2"],
	"min": 7000,
	"max": 20000}

# Új feladat:
kozeppont = Map.getCenter()
nehany_orszag = (orszagok.filter(ee.Filter.Or(
	ee.Filter.intersects(".geo", teglalap),
	ee.Filter.eq("COUNTRY_NA", "India"),
	ee.Filter.lte("Shape_Area", 30))))
Map.addLayer(eeObject = nehany_orszag, visParams = {}, name = "néhány ország")

masik_orszagok = (orszagok
	.filter(ee.Filter.isContained(".geo", nagyobb_teglalap))
	.filter(ee.Filter.rangeContains("Shape_Area", 10, 20)))
Map.addLayer(eeObject = masik_orszagok, visParams = {}, name = "másik országok")

honap_elejiek = (ee.ImageCollection("LANDSAT/LC09/C02/T1_L2")
	.filterBounds(kozeppont)
	.filter(ee.Filter.gt("SUN_AZIMUTH", 0))
	.filter(ee.Filter.rangeContains("CLOUD_COVER", 80, 100))
	.filter(ee.Filter.calendarRange(start = 1, end = 10, field = "day_of_month"))
	.filter(ee.Filter.dayOfYear(start = 100, end = 200)
	))
Map.addLayer(eeObject = honap_elejiek.mean(), visParams = megjelenites, name = "hónap elejiek átlaga")

